==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/client/base/i_connection_factory.h <==
/*
   Copyright (c) 2014, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_CONNECTION_FACTORY_INCLUDED
#define I_CONNECTION_FACTORY_INCLUDED

#include "client/client_priv.h"

namespace Mysql {
namespace Tools {
namespace Base {

/**
  Interface for classes that are capable of creating connection to
  MySQL database server.
 */
class I_connection_factory {
 public:
  virtual ~I_connection_factory() = default;

  /**
    Provides new connection to MySQL database server.
   */
  virtual MYSQL *create_connection() = 0;
};

}  // namespace Base
}  // namespace Tools
}  // namespace Mysql

#endif

==> mysql-8.0_8.0.42.orig.tar.gz: mysql-8.0.42/client/base/i_connection_factory.h <==
/*
   Copyright (c) 2014, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_CONNECTION_FACTORY_INCLUDED
#define I_CONNECTION_FACTORY_INCLUDED

#include "client/client_priv.h"

namespace Mysql {
namespace Tools {
namespace Base {

/**
  Interface for classes that are capable of creating connection to
  MySQL database server.
 */
class I_connection_factory {
 public:
  virtual ~I_connection_factory() = default;

  /**
    Provides new connection to MySQL database server.
   */
  virtual MYSQL *create_connection() = 0;
};

}  // namespace Base
}  // namespace Tools
}  // namespace Mysql

#endif
